@@ -231,7 +231,7 @@ int lldpctl_release(lldpctl_conn_t *conn);
  * translate this error code.
  *
  * When a function returns an integer, it may return a negative value. It
- * usually means this is an error but some functions may return a legetimate
+ * usually means this is an error but some functions may return a legitimate
  * negative value (for example @ref lldpctl_atom_get_int()). When there is a
  * doubt, @ref lldpctl_last_error() should be checked.
  *
@@ -489,6 +489,9 @@ typedef void (*lldpctl_change_callback)(lldpctl_conn_t *conn,
  * This function will register the necessity to push neighbor changes to lldpd
  * and therefore will issue IO operations. The error code could then be @c
  * LLDPCTL_ERR_WOULDBLOCK.
+ *
+ * Once a callback is registered, the connection shouldn't be used for anything
+ * else than receiving notifications.
  */
 int lldpctl_watch_callback(lldpctl_conn_t *conn,
     lldpctl_change_callback cb,
@@ -639,13 +642,13 @@ lldpctl_atom_t *lldpctl_get_default_port(lldpctl_conn_t *conn);
  * written. An atom marked with (IS) can be retrieved as an integer and features
  * an appropriate representation as a string (usually, the name of a constant)
  * which is more meaningful than just the integer. An atom marked as (I) can be
- * retrieved and as a string. In the later case, this is just a string
- * representation of the integer. An atom marked with (AL) can be retrieved as
- * an atom only and can be iterated over. This is usually a list of things. An
- * atom marked (I,W) can be read as an integer or a string and can be written as
- * an integer. The change would not be commited until the atom is written to the
- * nearest atom supporting (A,WO) operation (eventually with an indirection, i.e
- * first write to a (A,W), then to a (A,WO)).
+ * retrieved as an integer and as a string. In the later case, this is just a
+ * string representation of the integer. An atom marked with (AL) can be
+ * retrieved as an atom only and can be iterated over. This is usually a list of
+ * things. An atom marked (I,W) can be read as an integer or a string and can be
+ * written as an integer. The change would not be commited until the atom is
+ * written to the nearest atom supporting (A,WO) operation (eventually with an
+ * indirection, i.e first write to a (A,W), then to a (A,WO)).
  */
 typedef enum {
 	lldpctl_k_config_tx_interval, /**< `(I,WO)` Transmit interval. When set to -1, it is meant to transmit now. */
@@ -658,13 +661,16 @@ typedef enum {
 	lldpctl_k_config_hostname,	/**< `(S,WON)` System name overridden */
 	lldpctl_k_config_advertise_version, /**< `(I)` Advertise version */
 	lldpctl_k_config_lldpmed_noinventory, /**< `(I)` Disable LLDP-MED inventory */
-	lldpctl_k_config_paused,	      /**< `(I)` lldpd is paused */
+	lldpctl_k_config_paused,	      /**< `(I,WO)` lldpd is paused */
 	lldpctl_k_config_fast_start_enabled, /**< `(I,WO)` Is fast start enabled */
 	lldpctl_k_config_fast_start_interval, /**< `(I,WO)` Start fast transmit interval */
 	lldpctl_k_config_ifdescr_update, /**< `(I,WO)` Enable or disable setting interface description */
 	lldpctl_k_config_iface_promisc,  /**< `(I,WO)` Enable or disable promiscuous mode on interfaces */
 	lldpctl_k_config_chassis_cap_advertise, /**< `(I,WO)` Enable or disable chassis capabilities advertisement */
 	lldpctl_k_config_chassis_mgmt_advertise, /**< `(I,WO)` Enable or disable management addresses advertisement */
+	lldpctl_k_config_cid_string,    /**< `(S,WON)` User defined string for the chassis ID */
+	lldpctl_k_config_perm_iface_pattern, /**< `(S,WON)` Pattern of permanent interfaces */
+	lldpctl_k_config_tx_interval_ms, /**< `(I,WO)` Transmit interval in milliseconds. Set to -1 to transmit now. */
 
 	lldpctl_k_interface_name = 1000, /**< `(S)` The interface name. */
 
@@ -706,6 +712,22 @@ typedef enum {
 	lldpctl_k_dot3_power_allocated, /**< `(I,W)` 802.3AT power allocated */
 	lldpctl_k_dot3_power_requested, /**< `(I,W)` 802.3AT power requested */
 
+	/* 802.3bt additions */
+	lldpctl_k_dot3_power_pd_4pid, /**< `(IS,W)` 802.3BT both modes supported? */
+	lldpctl_k_dot3_power_requested_a, /**< `(I,W)` 802.3BT power value requested for A */
+	lldpctl_k_dot3_power_requested_b, /**< `(I,W)` 802.3BT power value requested for B */
+	lldpctl_k_dot3_power_allocated_a, /**< `(I,W)` 802.3BT power value allocated for A */
+	lldpctl_k_dot3_power_allocated_b, /**< `(I,W)` 802.3BT power value allocated for B */
+	lldpctl_k_dot3_power_pse_status, /**< `(IS,W)` 802.3BT PSE powering status */
+	lldpctl_k_dot3_power_pd_status, /**< `(IS,W)` 802.3BT PD powering status */
+	lldpctl_k_dot3_power_pse_pairs_ext, /**< `(IS,W)` 802.3BT PSE power pairs */
+	lldpctl_k_dot3_power_class_a, /**< `(IS,W)` 802.3BT power class for A */
+	lldpctl_k_dot3_power_class_b, /**< `(IS,W)` 802.3BT power class for B */
+	lldpctl_k_dot3_power_class_ext, /**< `(IS,W)` 802.3BT power class */
+	lldpctl_k_dot3_power_type_ext, /**< `(IS,W)` 802.3BT power type */
+	lldpctl_k_dot3_power_pd_load, /**< `(IS,W)` 802.3BT dualsig isolated? */
+	lldpctl_k_dot3_power_pse_max, /**< `(I,W)` 802.3BT maximum available power */
+
 	lldpctl_k_port_vlan_pvid = 1500, /**< `(I)` Primary VLAN ID */
 	lldpctl_k_port_vlans, /**< `(AL)` List of VLAN */
 	lldpctl_k_vlan_id, /**< `(I)` VLAN ID */
@@ -773,6 +795,7 @@ typedef enum {
 	lldpctl_k_med_power_val, /**< `(I,W)` LLDP MED power value */
 
 	lldpctl_k_mgmt_ip = 3000,	/**< `(S)` IP address */
+	lldpctl_k_mgmt_iface_index = 30001,	/**< `(I)` Interface index */
 
 	lldpctl_k_tx_cnt = 4000,	/**< `(I)` tx cnt. Only works for a local port. */
 	lldpctl_k_rx_cnt,	/**< `(I)` rx cnt. Only works for a local port. */
@@ -785,6 +808,7 @@ typedef enum {
 	lldpctl_k_config_bond_slave_src_mac_type, /**< `(I,WO)` bond slave src mac type. */
 	lldpctl_k_config_lldp_portid_type, /**< `(I,WO)` LLDP PortID TLV Subtype */
 	lldpctl_k_config_lldp_agent_type, /**< `(I,WO)` LLDP agent type */
+	lldpctl_k_config_max_neighbors, /**< `(I,WO)`Maximum number of neighbors per port. */
 
 	lldpctl_k_custom_tlvs = 5000,		/**< `(AL)` custom TLVs */
 	lldpctl_k_custom_tlvs_clear,		/** `(I,WO)` clear list of custom TLVs */
@@ -1030,10 +1054,10 @@ lldpctl_atom_t *lldpctl_atom_iter_value(lldpctl_atom_t *atom, lldpctl_atom_iter_
  * reference count of the provided value is decremented. If you need to use it
  * outside of the loop, you need to increment it.
  */
-#define lldpctl_atom_foreach(atom, value)				\
-	for (lldpctl_atom_iter_t *iter = lldpctl_atom_iter(atom);	\
-	     iter && (value = lldpctl_atom_iter_value(atom, iter));	\
-	     iter = lldpctl_atom_iter_next(atom, iter),			\
+#define lldpctl_atom_foreach(atom, value)						\
+	for (lldpctl_atom_iter_t *iter##_LINE_ = lldpctl_atom_iter(atom);		\
+	     iter##_LINE_ && (value = lldpctl_atom_iter_value(atom, iter##_LINE_));	\
+	     iter##_LINE_ = lldpctl_atom_iter_next(atom, iter##_LINE_),			\
 		 lldpctl_atom_dec_ref(value))
 
 /**
